@@ -1,15 +1,12 @@
-import sys
-
 import json
+import sys
+from datetime import datetime
+from datetime import timedelta
 
 import requests
 
-from datetime import datetime, timedelta
-
-
 this = sys.modules[__name__]
 
-
 this._GLOBAL_access_token = None
 this._GLOBAL_expires_in = None
 this._GLOBAL_refresh_token = None
@@ -48,11 +45,11 @@ def configfile(filename):
     if "start" in config_json:
         pass
     else:
-        start = None
+        pass
     if "end" in config_json:
         pass
     else:
-        end = None
+        pass
 
 
 def update(
